==> glftpd_bsd_1.16.9.tgz: glftpd_BSD_1.16.9/glinstall.sh <==
#!/bin/sh
#####################################################
# This script was written by inCIDenT@CyberDuDe.CoM #
# V1.02                                             #
# BSD Detect and tcpd location reassign by JabberA  #
# Edited by Archimede                               #
#####################################################
clear
echo "[-----------------------------------------------]"
echo "[       Glftpd Installation script V1.02        ]"
echo "[       --------------------------------        ]"
echo "[  This is a beta and may not work, please use  ]"
echo "[  at yer own peral                             ]"
echo "[                        -inCIDenT@CyberDuDe.CoM]"
echo "[-----------------------------------------------]"
echo 
echo -n "     Doing Sanity Checks..."
if [ ! "$USER" = "root" ]; then
echo "You must be root to install Glftpd!"
echo "Please exit and type su - root"
exit 0
fi
if test ! -r `pwd`/bin/glftpd; then
echo "Cannot find source directory!"
exit 0
fi
HOSTBSD=`uname -a |grep BSD`
if [ "$test" = "" ]; then
   TCPDTHING=/usr/sbin/tcpd
else
   TCPDTHING=/usr/libexec/tcpd
fi
echo "done" 
echo " [x] Installing GlFTPD on "`uname -msn`
echo " [x] Source Directory: "`pwd`
echo " [x] Installation. Directory: /glftpd"
echo
echo "[- - - -                               - - - - -]"
echo "[      Press return to start the Install        ]"
echo "[- - - -                               - - - - -]"
read $NULL
echo -n "Making Directory..."
mkdir /glftpd
echo "Done..."
echo -n "Moving package to Directory..."
mv * /glftpd
cp /lib/* /glftpd/lib
echo "Done..."
echo -n "Making Psuedo Devices..."
cd /glftpd/dev
mknod -m666 null c 1 3
mknod -m666 zero c 1 5
echo "Done..."
echo -n "Checking Binaries..."
cp /sbin/ldconfig /glftpd/bin
echo "Ignore the above error"
bindir="/glftpd/bin"
progs="sh kill cat echo grep unzip"
for i in $progs; do 
	cp `which $i` /glftpd/bin
done
echo "Done..."
echo -n "Configuring dependencies"
chroot /glftpd /bin/ldconfig > /dev/null
echo "Done..."
echo "Setting permissions"
chmod 755 /glftpd ; cd /glftpd ; chmod -R 755 bin/ lib/
echo "Make sure you check yer permissions."
echo "Done..."
echo
echo
echo "[- - - -                      - - - - -]"
echo "[      Press return to continue        ]"
echo "[- - - -                      - - - - -]"
read $NULL
mv /glftpd/glftpd.conf-EXTREME /etc/glftpd.conf
echo -n "Configuring inetd.conf..."
echo "glftpd	stream	tcp	nowait	root	$TCPDTHING	/glftpd/bin/glftpd -l -o -i" >> /etc/inetd.conf
echo "The entry is at the end of the file"
echo
echo "[- -                                          ]"
echo "[ What port would you like GlFTPD to run on ? ]"
echo "[                                          - -]"
echo -n "Port: "
read port
echo -n "Configuring Services..."
echo "glftpd	$port/tcp" >> /etc/services
echo "Done..."
echo -n "Restarting Inetd..."
killall -HUP inetd
echo "Done..."
echo
echo
echo "[-----------------------------------------------]"
echo "[       Glftpd Installation script V1.00        ]"
echo "[       --------------------------------        ]"
echo "[                                               ]"
echo "[     Glftpd has been sucessfully installed.    ]"
echo "[      Please refer to the manual for help      ]"
echo "[                                               ]"
echo "[  You will now be presented with a editor to   ]"
echo "[    configure Glftpd's configuration file.     ]"
echo "[                                               ]"
echo "[   For more information about Glftpd, visit    ]"
echo "[  http://glftpd.deepwell.com or #glftpd@EFnet  ]"
echo "[                                               ]" 
echo "[                        -inCIDenT@CyberDuDe.CoM]"
echo "[-----------------------------------------------]"
echo 
echo "[- - - -                               - - - - -]"
echo "[       Press return to start the editor        ]"
echo "[- - - -                               - - - - -]"
read $NULL
if test ! -z $EDITOR; then
$EDITOR /etc/glftpd.conf
exit 0
fi
if test -x `which pico`; then
`which pico` /etc/glftpd.conf
exit 0
fi
if test -x `which joe`; then
`which joe` /etc/glftpd.conf
exit 0
fi
if test -x `which vi`; then
`which vi` /etc/glftpd.conf
exit 0
fi
echo
echo "Could not find a usable file editor!"
echo "Please locate one yourself and edit /etc/glftpd.conf"

==> glftpd_bsd_1.17.0.tgz: glftpd_BSD_1.17.0/glinstall.sh <==
#!/bin/sh
ver="1.03"
############################################################################
# Program Name: Glftpd Installer                                           #
# Program  Ver: 1.03                                                       #
# Purpose:      To install GLftpd                                          #
# Dependancies: GLFTPD Dist. available from http://glftpd.deepwell.com     #
# Notes:        none                                                       #
# Installation: cd into the untarred directory, then run sh ./glinstall.sh #
############################################################################
# Modifications:(Please mail a copy of your changes to arch1mede@yahoo.com #
#                                                                          #
#  Modification                                            Name            #
#  ############                           #                ####            #
# BSD Detect and tcpd location reassign   #               JabberA          #
# Design Edit                             #               Archimede        # 
# TCPD Fixed                              #               inCIDenT         #
############################################################################
clear
echo "[-----------------------------------------------]"
echo "[       Glftpd Installation script $ver         ]"
echo "[       --------------------------------        ]"
echo "[  This is a beta and may not work, please use  ]"
echo "[  at yer own peral                             ]"
echo "[                        -inCIDenT@CyberDuDe.CoM]"
echo "[-----------------------------------------------]"
echo 
echo -n " Doing Sanity Checks..."
echo "You must be root to install Glftpd!"
if [ ! "$whoami-result = "root" ]; then
whoami-result=`whoami`
fi
exit 0
if test ! -r `pwd`/bin/glftpd; then
echo "Cannot find source directory!"
exit 0
fi
if [ -x "/usr/libexec/tcpd" ]; then
   TCPD=/usr/libexec/tcpd
else
   TCPD=/usr/sbin/tcpd
fi
echo "done" 
echo " [x] Installing GlFTPD on "`uname -msn`
echo " [x] Source Directory: "`pwd`
echo " [x] Installation. Directory: /glftpd"
echo
echo "[- - - -                               - - - - -]"
echo "[      Press return to start the Install        ]"
echo "[- - - -                               - - - - -]"
read $NULL
echo -n "Making Directory..."
mkdir /glftpd
echo "Done..."
echo -n "Moving package to Directory..."
mv * /glftpd
cp /lib/* /glftpd/lib
echo "Done..."
echo -n "Making Psuedo Devices..."
cd /glftpd/dev
mknod -m666 null c 1 3
mknod -m666 zero c 1 5
echo "Done..."
echo -n "Checking Binaries..."
cp /sbin/ldconfig /glftpd/bin
echo "Ignore the following errors"
bindir="/glftpd/bin"
progs="sh kill cat echo grep unzip ls bash wc"
for i in $progs; do 
	cp `which $i` /glftpd/bin
done
echo "Done..."
echo -n "Configuring dependencies"
chroot /glftpd /bin/ldconfig > /dev/null
echo "Done..."
echo "Setting permissions"
chmod -R 755 /glftpd ; cd /glftpd ; chmod 777 site/
echo "Make sure you check your permissions."
echo "Done..."
echo
echo
echo "[- - - -                      - - - - -]"
echo "[      Press return to continue        ]"
echo "[- - - -                      - - - - -]"
read $NULL
mv /glftpd/glftpd.conf-EXTREME /etc/glftpd.conf
echo -n "Configuring inetd.conf..."
echo "glftpd	stream	tcp	nowait	root	$TCPD	/glftpd/bin/glftpd -l -o -i" >> /etc/inetd.conf
echo "The entry is at the end of the file"
echo
echo "[- -                                          ]"
echo "[ What port would you like GlFTPD to run on ? ]"
echo "[                                          - -]"
echo -n "Port: "
read port
echo -n "Configuring Services..."
echo "glftpd	$port/tcp" >> /etc/services
echo "Done..."
echo -n "Restarting Inetd..."
killall -HUP inetd
echo "Done..."
echo
echo
echo "[-----------------------------------------------]"
echo "[       Glftpd Installation script $ver         ]"
echo "[       --------------------------------        ]"
echo "[                                               ]"
echo "[     Glftpd has been sucessfully installed.    ]"
echo "[      Please refer to the manual for help      ]"
echo "[                                               ]"
echo "[  You will now be presented with a editor to   ]"
echo "[    configure Glftpd's configuration file.     ]"
echo "[                                               ]"
echo "[   For more information about Glftpd, visit    ]"
echo "[  http://glftpd.deepwell.com or #glftpd@EFnet  ]"
echo "[                                               ]" 
echo "[                        -inCIDenT@CyberDuDe.CoM]"
echo "[-----------------------------------------------]"
echo 
echo "[- - - -                               - - - - -]"
echo "[       Press return to start the editor        ]"
echo "[- - - -                               - - - - -]"
read $NULL
if test ! -z $EDITOR; then
$EDITOR /etc/glftpd.conf
exit 0
fi
if test -x `which pico`; then
`which pico` /etc/glftpd.conf
exit 0
fi
if test -x `which joe`; then
`which joe` /etc/glftpd.conf
exit 0
fi
if test -x `which vi`; then
`which vi` /etc/glftpd.conf
exit 0
fi
echo
echo "Could not find a usable file editor!"
echo "Please locate one yourself and edit /etc/glftpd.conf"
